Background

Struct Background 

pub struct Background { /* private fields */ }
A handle to a reactor running on a background thread. This can be used to ensure that the reactor is being constantly polled without blocking another thread.

Implementations

Source

impl Background

pub fn new(reactor: Reactor) -> Result<Self>

Creates a new background thread which polls the given reactor. All errors returned during the creation of the ReactorThread will be propagated.

pub fn handle(&self) -> Handle

Returns a handle to inner reactor.

pub fn register<E: Evented>( &self, resource: &E, interest: Ready, opts: PollOpt, ) -> Result<Arc<IoWaker>>

Registers a new IO resource with this reactor.

pub fn reregister<E: Evented>( &self, resource: &E, io_waker: &IoWaker, interest: Ready, opts: PollOpt, ) -> Result<()>

pub fn deregister<E: Evented>( &self, resource: &E, io_waker: &IoWaker, ) -> Result<()>

Stops tracking notifications from the provided IO resource.

pub fn shutdown_now(&mut self) -> Result<()>

Shuts down the thread where the reactor is being polled, panicking if the reactor can not be woken up, and returning any errors which happened in the thread where the reactor was being polled.